@@ -63,7 +63,7 @@ int main(int argc, char *argv[])
 
   if (app.isSessionRestored())
   {
-    RESTORE(KmagApp);
+    kRestoreMainWindows<KmagApp>();
   }
   else
   {
